use ExtUtils::MakeMaker;
WriteMakefile(
    NAME           => 'abr',
    VERSION        => '0.1',
    ABSTRACT       => 'Password insertion',
    AUTHOR         => 'Tom Jones <tom.jones@oucs.ox.ac.uk>',
    EXE_FILES      => [ glob('bin/*') ],
    PL_FILES => {'yp_to_pm' => 'blib/Abr/TemplateYapp.pm'}
);

# copied from razor-agents Makefile.PL
{
    package MY;

    sub constants {
        my $self = shift;
    
        my $inherited = $self->SUPER::constants(@_);

        my $prefix = $ExtUtils::MakeMaker::VERSION >= 6.18 ? 'SITEPREFIX' :
                                                         'PERLPREFIX';

        my $man5 = sprintf <<'EOF', $prefix;
# begin abr
MAN5PODS = doc/abr.conf
INST_MAN5DIR = blib/man5
INSTALLMAN5DIR = $(DESTDIR)$(PREFIX)/share/man/man5
INSTALLSITEMAN5DIR = $(DESTDIR)$(SITEPREFIX)/share/man/man5
INSTALLVENDORMAN5DIR = $(DESTDIR)$(VENDORPREFIX)/share/man/man5
MAN5EXT = 5
# end abr

EOF


        return $inherited . $man5;
    }


    sub MY::top_targets {
        my $self = shift;

        use Config;
        my $inherited = $self->SUPER::top_targets(@_);

        my ($perlh) = $self->catfile($Config{archlibexp}, 'CORE', "perl.h");

        my $noecho = q{NOECHO = @} unless $inherited =~ /NOECHO/;

        my $man5 = sprintf <<'EOF', $perlh, $perlh;

# begin abr
config :: $(INST_MAN5DIR)/.exists
	@$(NOOP)

$(INST_MAN5DIR)/.exists :: %s
	@$(MKPATH) $(INST_MAN5DIR)
	@$(EQUALIZE_TIMESTAMP) %s $(INST_MAN5DIR)/.exists
	-@$(CHMOD) $(PERM_RWX) $(INST_MAN5DIR)
# end abr

EOF


        return $inherited . $man5;
    }


    sub MY::manifypods {
        my $self = shift;
        my $inherited = $self->SUPER::manifypods(@_);

        $inherited =~ s{^(manifypods : .*)\\}{$1 manifypods-abr \\}m;

        # MakeMaker 6.06_x through 6.13 eliminated the POD2MAN macro.
        my $pod2man = $inherited =~ /^POD2MAN\b/m ? ''
                                              : 'POD2MAN = $(POD2MAN_EXE)';

        my $manifypods_abr = sprintf <<'MAKE_FRAG', $pod2man;

# begin abr
%s

manifypods-abr : doc/abr.conf
	$(POD2MAN) --section=5 \
	doc/abr.conf \
	$(INST_MAN5DIR)/abr.conf.$(MAN5EXT)

#end abr
MAKE_FRAG

        return $inherited . "\n" . $manifypods_abr;
    }


    sub MY::install {
        my $self = shift;
  
        my $inherited = $self->SUPER::install(@_);

        my $man5 = q{ \\
	        $(INST_MAN5DIR) $(INSTALLMAN5DIR)};

        $inherited =~ s/(\$\((?:DEST)?INSTALL\w*MAN1DIR\))/$1$man5/gm;

        return $inherited;
    }
}
