use strict;

use Cwd;
use Data::Dumper;
use Expect;
use IO::File;
use Test::More 'no_plan';

use Fatal qw(open);

my $cwd = getcwd;
my $keyfilepath = "$cwd/t/data/passwords/abr_pass.key";
my $cfpath = "$cwd/t/data/etc/abr.conf.1";
my $mode = "0640";

my $cfdata = <<EOT;
- path: $keyfilepath
  mechanism: file
  mode: $mode
EOT

my $keyblockdata = <<'EOT';
THIS IS A
VERY SECRET
KEY BLOCK
EOT

open(my $cf, ">", $cfpath);
print $cf $cfdata;
close $cf;

my @cmd = ("./blib/script/abr", '--config' => $cfpath, -dr => $keyfilepath);
my $exp = Expect->new;
$exp->raw_pty(1);
$exp->log_stdout(0);
$exp->spawn(@cmd);

my %res;
my @fields = qw(pos err str before after);
@res{@fields} = $exp->expect(
    5, -re => 'Please arrange for the key to appear in .*?\r?$',
);

#print Dumper(%res);

$res{str} =~ /Please arrange for the key to appear in (\S+)\r?$/;

my $keyblocktarg = $1;

my $keyblock = IO::File->new($keyblocktarg, O_TRUNC|O_RDWR|O_CREAT);
if (!defined($keyblock)) {
    die "$!: $keyblocktarg\n";
}

print $keyblock $keyblockdata;
$keyblock->flush;
$keyblock->close;
undef $keyblock;

@res{@fields} = $exp->expect(5, "Hit enter when done>");
#print Dumper %res;

$exp->send("\n");
$exp->soft_close;
is($exp->exitstatus, 0, "exit with success when specifying path on command line");

is(`cat $keyfilepath`, $keyblockdata, 
  "configured keyfile now contains key data");

ok(system("ls $keyblocktarg 2>/dev/null"), "tmp file no longer exists");

ok($mode eq sprintf("%04o", ((stat($keyfilepath))[2] & 0777)), "mode is $mode");
